import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def argparse_create() -> None: ...
def call_handle_checked(fn, *, do_register, all_users) -> None: ...
def filepath_ensure_removed(path) -> None: ...
def filepath_repr(filepath) -> None: ...
def handle_bin(do_register, all_users) -> None: ...
def handle_desktop_file(do_register, all_users) -> None: ...
def handle_icon(do_register, all_users) -> None: ...
def handle_mime_association_default(do_register, all_users) -> None: ...
def handle_mime_association_xml(do_register, all_users) -> None: ...
def handle_thumbnailer(do_register, all_users) -> None: ...
def main() -> None: ...
def main_run_as_root(do_register, *, python_args) -> None: ...
def register(all_users=False) -> None: ...
def register_impl(do_register, all_users) -> None: ...
def system_path_contains(dirpath) -> None: ...
def unregister(all_users=False) -> None: ...
