import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def do_clear_previews(
    do_objects, do_collections, do_scenes, do_data_intern
) -> None: ...
def do_previews(do_objects, do_collections, do_scenes, do_data_intern) -> None: ...
def ids_nolib(bids) -> None: ...
def ids_nolib_with_preview(bids) -> None: ...
def main() -> None: ...
def rna_backup_gen(data, include_props=None, exclude_props=None, root=()) -> None: ...
def rna_backup_restore(data, backup) -> None: ...
